@@ -13,6 +13,10 @@ import sys
 import socket
 import subprocess as sp
 
+
+import re
+# valid alphas in rpname
+
 NOTIF = True
 try:
     from notifator.telegram import bot_send
@@ -34,8 +38,11 @@ def call_notifator(msg):
     else:
         print("q... notifator not installed...")
 
-def call_command(CMD):
+def call_command(CMD, debug=False):
     res = "X... apriori error when calling CMD"
+    print("_____________________________________________ calling command:")
+    print(CMD)
+    print("_____________________________________________")
     try:
         res=sp.check_output( CMD, shell=True ).decode("utf8").rstrip().split("\n")
     except sp.CalledProcessError as e:
@@ -64,6 +71,9 @@ def get_path_reponame_host(folder, debug=False):
             rpname = rpname.replace("/","")
             rpname = rpname.replace(" ","")
             print("i... but it is a folder... rpname==>", rpname)
+
+    # only alphabet characters
+    rpname = re.sub(r"[^A-Za-z0-9_]+", '', rpname)
     print("D... FONAME REPONAME: ",foname,"rpname",rpname)
     return foname,rpname,host
 
@@ -86,16 +96,18 @@ def init( debug = False, configfile=""):
     return True
 
 
-
 def create(folder, debug = False, configfile=""):
     """ borg create ssh://borg@***:2222/config/borg::host_folder
     """
     global print
     print=super_print(debug)(print)
+    print("D... ","loading config in <create>")
     conf.load_config(configfile)
+    print("D... ",conf)
     foname,rpname,host = get_path_reponame_host(folder,debug)
 
-    CMD = "borg create --stats --progress --compression zstd,9 ssh://borg@{}:2222/config/borg::{}_{}_`date +%Y%m%d_%H%M%S`  {}".format(
+
+    CMD = "borg create --stats --progress --compression zstd,9 ssh://borg@{}:2222/config/borg::{}_{}_`date +%Y%m%d_%H%M%S`  '{}'".format(
         conf.CONFIG['remote'],
         host,
         rpname,
@@ -103,7 +115,7 @@ def create(folder, debug = False, configfile=""):
         )
     print(CMD)
     # direct terminal output
-    res = call_command( CMD )
+    res = call_command( CMD , debug=debug)
     #res=sp.check_output( CMD, shell=True ).decode("utf8").rstrip().split("\n")
     print(res)
     return True
@@ -119,6 +131,7 @@ def prune(folder, debug = False, configfile=""):
 
     foname,rpname,host = get_path_reponame_host(folder,debug)
 
+
     CMD = "borg prune ssh://borg@{}:2222/config/borg   --keep-daily=7 --keep-weekly=8 --keep-monthly=-1  -P {}".format(
         conf.CONFIG['remote'],
         host+"_"+rpname
@@ -189,6 +202,7 @@ def extract( debug = False, configfile=""):
     print=super_print(debug)(print)
     foname,rpname,host = get_path_reponame_host(".", debug)
 
+
     CMD = "borg extract --dry-run --list ssh://borg@{}:2222/config/borg::{}_{}".format(
         conf.CONFIG['remote'],
         host,
